@@ -1,11 +1,11 @@
 package HPC::Runner::Command::execute_job::Logger::Lock;
 
 use Moose::Role;
-
 use namespace::autoclean;
+
 use Try::Tiny;
-use Path::Tiny;
-use File::Slurp;
+use Time::HiRes;
+use File::Spec;
 use MooseX::Types::Path::Tiny qw/Path Paths AbsPath AbsFile/;
 
 has 'lock_file' => (
@@ -16,12 +16,17 @@ has 'lock_file' => (
     required => 1,
     default  => sub {
         my $self = shift;
-        my $file =
-            File::Spec->catdir($self->data_dir,  '.lock' );
+        my $file = File::Spec->catdir( $self->data_dir, '.lock' );
         return $file;
     },
 );
 
+has 'logger' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => 'command_log',
+);
+
 =head3 check_lock
 
 Check to see if the lock exists
@@ -31,32 +36,37 @@ Have a max retry count to avoid infinite loops
 =cut
 
 sub check_lock {
-    my $self     = shift;
+    my $self = shift;
 
-    my $max_retries = 1000;
+    my $max_retries = 100;
     my $x           = 0;
 
+    my $ret = 1;
     while ( $self->lock_file->exists ) {
-        $self->command_log->info('Lock exists!');
         Time::HiRes::sleep(0.5);
         $x++;
-        last if $x >= $max_retries;
+        if($x >= $max_retries){
+          $ret = 0;
+          last;
+        }
     }
     if ( $x >= $max_retries ) {
-        $self->command_log->warn(
-            'Logger::JSON Error: We exited the lock!'  );
+        $self->{$self->logger}->warn('Logger::JSON Error: We exited the lock!');
     }
+
+    return $ret;
 }
 
 sub write_lock {
-    my $self     = shift;
+    my $self = shift;
 
     try {
         $self->lock_file->touchpath;
     }
     catch {
-        $self->command_log->warn(
-            'Logger::JSON Error: We were not able to write ' . $self->lock_file->stringify );
+        $self->{$self->logger}->warn(
+            'Logger::JSON Error: We were not able to write '
+              . $self->lock_file->stringify );
     };
 }
 
