@@ -1,7 +1,7 @@
 package HPC::Runner::Command::submit_jobs::Plugin::Slurm;
 
 use Data::Dumper;
-use Log::Log4perl;
+# use Log::Log4perl;
 use File::Temp qw/ tempfile /;
 use File::Slurp;
 use File::Spec;
@@ -96,27 +96,6 @@ EOF
       q{Path to Slurm template file if you do not wish to use the default}
 );
 
-##Application log
-##There is a bug in here somewhere - this be named anything ...
-has 'log' => (
-    is      => 'rw',
-    default => sub {
-        my $self = shift;
-
-        my $log_conf = q(
-log4perl.rootLogger = DEBUG, Screen
-log4perl.appender.Screen = \
-  Log::Log4perl::Appender::ScreenColoredLevels
-log4perl.appender.Screen.layout = \
-  Log::Log4perl::Layout::PatternLayout
-log4perl.appender.Screen.layout.ConversionPattern = \
-  [%d] %m %n
-      );
-        Log::Log4perl::init( \$log_conf );
-        return Log::Log4perl->get_logger();
-    }
-);
-
 =head2 Subroutines
 
 =cut
@@ -142,9 +121,9 @@ sub submit_jobs {
     sleep(3);
 
     if ( ! defined $exitcode || $exitcode != 0 ) {
-        $self->log->fatal("Job was not submitted successfully");
-        $self->log->warn( "STDERR: " . $stderr ) if $stderr;
-        $self->log->warn( "STDOUT: " . $stdout ) if $stdout;
+        $self->app_log->fatal("Job was not submitted successfully");
+        $self->app_log->warn( "STDERR: " . $stderr ) if $stderr;
+        $self->app_log->warn( "STDOUT: " . $stdout ) if $stdout;
     }
 
     my ($jobid) = $stdout =~ m/(\d.*)$/ if $stdout;
@@ -153,7 +132,7 @@ sub submit_jobs {
         $self->job_failure;
     }
     else {
-        $self->log->debug( "Submited job "
+        $self->app_log->info( "Submitted job "
               . $self->slurmfile
               . "\n\tWith Slurm jobid $jobid" );
     }
